@@ -4,6 +4,7 @@ import os
 
 import portability
 
-VERSION = '4.0.2'
+VERSION = '4.0.3'
 HOME_DIR = portability.get_home_directory()
-COMIX_DIR = portability.get_comix_directory()
+CONFIG_DIR = portability.get_config_directory()
+DATA_DIR = portability.get_data_directory()
